@@ -45,6 +45,7 @@
    wait-for-event
    make-tag
    thread-for-evaluation
+   socket-quest
 
    authenticate-client
    encode-message
@@ -134,8 +135,7 @@ DEDICATED-OUTPUT INPUT OUTPUT IO REPL-RESULTS"
 Return an output stream suitable for writing program output.
 
 This is an optimized way for Lisp to deliver output to Emacs."
-  (let ((socket (create-socket *loopback-interface*
-                               *dedicated-output-stream-port*))
+  (let ((socket (socket-quest *dedicated-output-stream-port* nil))
         (ef (find-external-format-or-lose coding-system)))
     (unwind-protect
          (let ((port (local-port socket)))
