@@ -17,11 +17,10 @@
   (require :sock)
   (require :process)
   #+(version>= 8 2)
-  (require 'lldb)
-  )
+  (require 'lldb))
 
 (defimplementation gray-package-name ()
-  "EXCL")
+  '#:excl)
 
 ;;; swank-mop
 
@@ -33,13 +32,13 @@
 
 ;;;; UTF8
 
-(define-symbol-macro utf8-ef 
-    (load-time-value 
+(define-symbol-macro utf8-ef
+    (load-time-value
      (excl:crlf-base-ef (excl:find-external-format :utf-8))
      t))
 
 (defimplementation string-to-utf8 (s)
-  (excl:string-to-octets s :external-format utf8-ef 
+  (excl:string-to-octets s :external-format utf8-ef
                          :null-terminate nil))
 
 (defimplementation utf8-to-string (u)
@@ -52,7 +51,7 @@
   :spawn)
 
 (defimplementation create-socket (host port &key backlog)
-  (socket:make-socket :connect :passive :local-port port 
+  (socket:make-socket :connect :passive :local-port port
                       :local-host host :reuse-address t
                       :backlog (or backlog 5)))
 
@@ -74,8 +73,8 @@
   (excl::stream-input-handle stream))
 
 (defvar *external-format-to-coding-system*
-  '((:iso-8859-1 
-     "latin-1" "latin-1-unix" "iso-latin-1-unix" 
+  '((:iso-8859-1
+     "latin-1" "latin-1-unix" "iso-latin-1-unix"
      "iso-8859-1" "iso-8859-1-unix")
     (:utf-8 "utf-8" "utf-8-unix")
     (:euc-jp "euc-jp" "euc-jp-unix")
@@ -85,8 +84,8 @@
 (defimplementation find-external-format (coding-system)
   (let ((e (rassoc-if (lambda (x) (member coding-system x :test #'equal))
                       *external-format-to-coding-system*)))
-    (and e (excl:crlf-base-ef 
-            (excl:find-external-format (car e) 
+    (and e (excl:crlf-base-ef
+            (excl:find-external-format (car e)
                                        :try-variant t)))))
 
 ;;;; Unix signals
@@ -137,7 +136,7 @@
 
 (defimplementation describe-definition (symbol namespace)
   (ecase namespace
-    (:variable 
+    (:variable
      (describe symbol))
     ((:function :generic-function)
      (describe (symbol-function symbol)))
@@ -234,7 +233,7 @@
                          (car (debugger:frame-expression frame))))))))))
 
 (defun function-source-location (fun)
-  (cadr (car (fspec-definition-locations 
+  (cadr (car (fspec-definition-locations
               (xref::object-to-function-name fun)))))
 
 #+(version>= 8 2)
@@ -295,7 +294,7 @@
 (defun source-paths-of (whole part)
   (let ((result '()))
     (labels ((walk (form path)
-               (cond ((eq form part) 
+               (cond ((eq form part)
                       (push (reverse path) result))
                      ((consp form)
                       (loop for i from 0 while (consp form) do
@@ -324,9 +323,9 @@
 
 (defimplementation return-from-frame (frame-number form)
   (let ((frame (nth-frame frame-number)))
-    (multiple-value-call #'debugger:frame-return 
-      frame (debugger:eval-form-in-context 
-             form 
+    (multiple-value-call #'debugger:frame-return
+      frame (debugger:eval-form-in-context
+             form
              (debugger:environment-of-frame frame)))))
 
 (defimplementation frame-restartable-p (frame)
@@ -399,7 +398,7 @@
 (defun location-for-warning (condition)
   (let ((loc (getf (slot-value condition 'excl::plist) :loc)))
     (cond (*buffer-name*
-           (make-location 
+           (make-location
             (list :buffer *buffer-name*)
             (list :offset *buffer-start-position* 0)))
           (loc
@@ -432,14 +431,14 @@
           (dolist (loc locs)
             (multiple-value-bind (pos file) (ecase (length loc)
                                               (2 (values-list loc))
-                                              (3 (destructuring-bind 
+                                              (3 (destructuring-bind
                                                        (start end file) loc
                                                    (declare (ignore end))
                                                    (values start file))))
               (signal-compiler-condition
                :original-condition condition
                :severity :warning
-               :message (format nil "Undefined function referenced: ~S" 
+               :message (format nil "Undefined function referenced: ~S"
                                 fname)
                :location (make-location (list :file file)
                                         (list :position (1+ pos)))))))))
@@ -450,7 +449,7 @@
                  (reader-error  #'handle-compiler-warning))
     (funcall function)))
 
-(defimplementation swank-compile-file (input-file output-file 
+(defimplementation swank-compile-file (input-file output-file
                                        load-p external-format
                                        &key policy)
   (declare (ignore policy))
@@ -458,7 +457,7 @@
       (with-compilation-hooks ()
         (let ((*buffer-name* nil)
               (*compile-filename* input-file))
-          (compile-file *compile-filename* 
+          (compile-file *compile-filename*
                         :output-file output-file
                         :load-after-compile load-p
                         :external-format external-format)))
@@ -500,14 +499,14 @@ to do this, this factors in the length of the inserted header itself."
                                            (length position-form-string))
                                         :initial-element #\;)))
       (write-string source-pathname-string stream)
-      (write-string position-form-string stream)  
+      (write-string position-form-string stream)
       (write-string padding-string stream)
       (write-char #\newline stream))))
 
 (defun compile-from-temp-file (string buffer offset file)
-  (call-with-temp-file 
+  (call-with-temp-file
    (lambda (stream filename)
-     (when (and file offset (probe-file file)) 
+     (when (and file offset (probe-file file))
        (write-tracking-preamble stream file offset))
      (write-string string stream)
      (finish-output stream)
@@ -537,7 +536,7 @@ to do this, this factors in the length of the inserted header itself."
 (defimplementation swank-compile-string (string &key buffer position filename
                                          policy)
   (declare (ignore policy))
-  (handler-case 
+  (handler-case
       (with-compilation-hooks ()
         (let ((*buffer-name* buffer)
               (*buffer-start-position* position)
@@ -549,13 +548,13 @@ to do this, this factors in the length of the inserted header itself."
 
 (defun buffer-or-file (file file-fun buffer-fun)
   (let* ((probe (gethash file *temp-file-map*)))
-    (cond (probe 
+    (cond (probe
            (destructuring-bind (buffer start) probe
              (funcall buffer-fun buffer start)))
           (t (funcall file-fun (namestring (truename file)))))))
 
 (defun buffer-or-file-location (file offset)
-  (buffer-or-file file 
+  (buffer-or-file file
                   (lambda (filename)
                     (make-location `(:file ,filename)
                                    `(:position ,(1+ offset))))
@@ -597,7 +596,7 @@ to do this, this factors in the length of the inserted header itself."
                  (t
                   (find-definition-in-file fspec type file top-level)))))
         ((member :top-level)
-         (make-error-location "Defined at toplevel: ~A" 
+         (make-error-location "Defined at toplevel: ~A"
                               (fspec->string fspec))))
     (error (e)
       (make-error-location "Error: ~A" e))))
@@ -630,9 +629,9 @@ to do this, this factors in the length of the inserted header itself."
        (if (null defs)
            (list
             (list fspec
-                  (make-error-location "Unknown source location for ~A" 
+                  (make-error-location "Unknown source location for ~A"
                                        (fspec->string fspec))))
-           (loop for (fspec type file top-level) in defs collect 
+           (loop for (fspec type file top-level) in defs collect
                  (list (list type fspec)
                        (find-fspec-location fspec type file top-level))))))))
 
@@ -670,7 +669,7 @@ to do this, this factors in the length of the inserted header itself."
        (max (excl::function-constant-count function)))
       ((= i max))
     (let ((c (excl::function-constant function i)))
-      (cond ((and (functionp c) 
+      (cond ((and (functionp c)
                   (not (eq c function))
                   (plusp depth))
              (map-function-constants c fn (1- depth)))
@@ -678,12 +677,12 @@ to do this, this factors in the length of the inserted header itself."
              (funcall fn c))))))
 
 (defun in-constants-p (fun symbol)
-  (map-function-constants fun 
-                          (lambda (c) 
-                            (when (eq c symbol) 
+  (map-function-constants fun
+                          (lambda (c)
+                            (when (eq c symbol)
                               (return-from in-constants-p t)))
                           3))
- 
+
 (defun function-callers (name)
   (let ((callers '()))
     (do-all-symbols (sym)
@@ -750,7 +749,7 @@ to do this, this factors in the length of the inserted header itself."
            (prof:start-sampling)
            (unwind-protect (excl:call-next-fwrapper)
              (prof:stop-sampling))))
-        (t 
+        (t
          (excl:call-next-fwrapper))))
 
 (defimplementation profile (fname)
@@ -803,7 +802,7 @@ to do this, this factors in the length of the inserted header itself."
        (label-value-line name (inspect::component-ref-v object access type)))
       ((:lisp :value :func)
        (label-value-line name (inspect::component-ref object access)))
-      (:indirect 
+      (:indirect
        (destructuring-bind (prefix count ref set) access
          (declare (ignore set prefix))
          (loop for i below (funcall count object)
@@ -862,7 +861,7 @@ to do this, this factors in the length of the inserted header itself."
 
 (defvar *mailbox-lock* (mp:make-process-lock :name "mailbox lock"))
 
-(defstruct (mailbox (:conc-name mailbox.)) 
+(defstruct (mailbox (:conc-name mailbox.))
   (lock (mp:make-process-lock :name "process mailbox"))
   (queue '() :type list)
   (gate (mp:make-gate nil)))
@@ -877,7 +876,7 @@ to do this, this factors in the length of the inserted header itself."
 (defimplementation send (thread message)
   (let* ((mbox (mailbox thread)))
     (mp:with-process-lock ((mailbox.lock mbox))
-      (setf (mailbox.queue mbox) 
+      (setf (mailbox.queue mbox)
             (nconc (mailbox.queue mbox) (list message)))
       (mp:open-gate (mailbox.gate mbox)))))
 
@@ -904,7 +903,7 @@ to do this, this factors in the length of the inserted header itself."
     (declare (type symbol name))
     (mp:with-process-lock (lock)
       (etypecase thread
-        (null 
+        (null
          (setf alist (delete name alist :key #'car)))
         (mp:process
          (let ((probe (assoc name alist)))
@@ -937,14 +936,14 @@ to do this, this factors in the length of the inserted header itself."
 
 (defimplementation toggle-trace (spec)
   (ecase (car spec)
-    ((setf) 
+    ((setf)
      (toggle-trace-aux spec))
     (:defgeneric (toggle-trace-generic-function-methods (second spec)))
-    ((setf :defmethod :labels :flet) 
+    ((setf :defmethod :labels :flet)
      (toggle-trace-aux (process-fspec-for-allegro spec)))
     (:call
      (destructuring-bind (caller callee) (cdr spec)
-       (toggle-trace-aux callee 
+       (toggle-trace-aux callee
                          :inside (list (process-fspec-for-allegro caller)))))))
 
 (defun tracedp (fspec)
@@ -977,7 +976,7 @@ to do this, this factors in the length of the inserted header itself."
            ((:defmethod) `(method ,@(rest fspec)))
            ((:labels) `(labels ,(process-fspec-for-allegro (second fspec))
                          ,(third fspec)))
-           ((:flet) `(flet ,(process-fspec-for-allegro (second fspec)) 
+           ((:flet) `(flet ,(process-fspec-for-allegro (second fspec))
                        ,(third fspec)))))
         (t
          fspec)))
