@@ -420,7 +420,8 @@
   (etypecase name
     (null nil)
     (symbol (symbol-package name))
-    ((cons (eql setf) symbol) (symbol-package (cadr name)))
+    ((cons (eql ccl::traced)) (function-name-package (second name)))
+    ((cons (eql setf)) (symbol-package (second name)))
     ((cons (eql :internal)) (function-name-package (car (last name))))
     ((cons (and symbol (not keyword)) (cons list null))
      (symbol-package (car name)))
