@@ -29,8 +29,8 @@
    read-source-form
    source-path-string-position
    source-path-file-position
-   source-path-source-position
-   ))
+   source-path-source-position)
+  (:shadow ignore-errors))
 
 (in-package swank/source-path-parser)
 
@@ -40,6 +40,11 @@
 	      (nth-value 1 (get-macro-character #\space rt))))
   (assert (not (get-macro-character #\\ rt))))
 
+(eval-when (:compile-toplevel)
+  (defmacro ignore-errors (&rest forms)
+    ;;`(progn . ,forms) ; for debugging
+    `(cl:ignore-errors . ,forms)))
+
 (defun make-sharpdot-reader (orig-sharpdot-reader)
   (lambda (s c n)
     ;; We want things like M-. to work regardless of any #.-fu in
@@ -59,8 +64,17 @@ before and after of calling FN in the hashtable SOURCE-MAP."
       #+(or)
       (format t "[~D \"~{~A~^, ~}\" ~D ~D ~S]~%"
 	      start values end (char-code char) char)
-      (unless (null values)
-	(push (cons start end) (gethash (car values) source-map)))
+      (when values
+        (destructuring-bind (&optional existing-start &rest existing-end)
+            (car (gethash (car values) source-map))
+          ;; Some macros may return what a sub-call to another macro
+          ;; produced, e.g. "#+(and) (a)" may end up saving (a) twice,
+          ;; once from #\# and once from #\(. If the saved form
+          ;; is a subform, don't save it again.
+          (unless (and existing-start existing-end
+                       (<= start existing-start end)
+                       (<= start existing-end end))
+            (push (cons start end) (gethash (car values) source-map)))))
       (values-list values))))
 
 (defun make-source-recording-readtable (readtable source-map)
@@ -103,8 +117,23 @@ subexpressions of the object to stream positions."
       (push (cons start end) (gethash form source-map)))
     (values form source-map)))
 
-(defun skip-whitespace (stream)
-  (peek-char t stream))
+(defun starts-with-p (string prefix)
+  (declare (type string string prefix))
+  (not (mismatch string prefix
+		 :end1 (min (length string) (length prefix))
+		 :test #'char-equal)))
+
+(defun extract-package (line)
+  (declare (type string line))
+  (let ((name (cadr (read-from-string line))))
+    (find-package name)))
+
+#+(or)
+(progn
+  (assert (extract-package "(in-package cl)"))
+  (assert (extract-package "(cl:in-package cl)"))
+  (assert (extract-package "(in-package \"CL\")"))
+  (assert (extract-package "(in-package #:cl)")))
 
 ;; FIXME: do something cleaner than this.
 (defun readtable-for-package (package)
@@ -113,44 +142,41 @@ subexpressions of the object to stream positions."
   (funcall (read-from-string "swank::guess-buffer-readtable")
            (string-upcase (package-name package))))
 
-(defun skip-one-toplevel-form (stream read-suppress package readtable)
-  ;; Read one form trying to parse IN-PACKAGE forms.
-  ;; Return three values: (NEW-READ-SUPPRESS NEW-PACKAGE NEW-READTABLE).
-  (let ((form (let ((*read-suppress* read-suppress)
-		    (*package* package)
-		    (*readtable* readtable))
-		(read stream))))
-    (cond ((and (consp form)
-		(string= (car form) 'in-package))
-	   (let ((pkg (find-package (second form))))
-	     (if pkg
-		 (values nil pkg (readtable-for-package pkg))
-		 (values t package readtable))))
-	  (t
-	   (values nil package readtable)))))
-
-;; IDEA: maybe stop being so clever after the first IN-PACKAGE form.
+;; Search STREAM for a "(in-package ...)" form.  Use that to derive
+;; the values for *PACKAGE* and *READTABLE*.
 ;;
-;; IDEA: 1) skip over the form with *READ-SUPPRESS* 2) reset the file
-;; position 3) use READ-LINE and only if the line matches a pattern
-;; process it as IN-PACKAGE.
+;; IDEA: move GUESS-READER-STATE to swank.lisp so that all backends
+;; use the same heuristic and to avoid the need to access
+;; swank::guess-buffer-readtable from here.
+(defun guess-reader-state (stream)
+  (let* ((point (file-position stream))
+	 (pkg *package*))
+    (file-position stream 0)
+    (loop for line = (read-line stream nil nil) do
+	  (when (not line) (return))
+	  (when (or (starts-with-p line "(in-package ")
+		    (starts-with-p line "(cl:in-package "))
+	    (let ((p (extract-package line)))
+	      (when p (setf pkg p)))
+	    (return)))
+    (file-position stream point)
+    (values (readtable-for-package pkg) pkg)))
+
+(defun skip-whitespace (stream)
+  (peek-char t stream nil nil))
+
+;; Skip over N toplevel forms.
 (defun skip-toplevel-forms (n stream)
-  ;; Skip over N toplevel forms.  Try to be clever and and recognize
-  ;; the IN-PACKAGE form.  For this *READ-SUPPRESS* is NIL (i.e. lots
-  ;; of interning) until a non-existing package would be needed.
-  (let ((read-suppress nil)
-	(package *package*)
-	(readtable *readtable*))
-    (dotimes (_ n)
-      (multiple-value-setq (read-suppress package readtable)
-	(skip-one-toplevel-form stream read-suppress package readtable)))
-    (values package readtable)))
+  (let ((*read-suppress* t))
+    (dotimes (i n)
+      (read stream))
+    (skip-whitespace stream)))
 
 (defun read-source-form (n stream)
   "Read the Nth toplevel form number with source location recording.
 Return the form and the source-map."
-  (multiple-value-bind (*package* *readtable*) (skip-toplevel-forms n stream)
-    (skip-whitespace stream)
+  (multiple-value-bind (*readtable* *package*) (guess-reader-state stream)
+    (skip-toplevel-forms n stream)
     (read-and-record-source-map stream)))
 
 (defun source-path-stream-position (path stream)
@@ -194,9 +220,7 @@ of the deepest (i.e. smallest) possible form is returned."
 		     for f = form then (nth n f)
 		     collect f)))
     ;; select the first subform present in source-map
-    (loop for form in (reverse forms)
-	  for positions = (gethash form source-map)
-	  while positions
-	  when (null (cdr positions))
-	  return (destructuring-bind ((start . end)) positions
-		   (return (values start end))))))
+    (loop for form in (nreverse forms)
+	  for ((start . end) . rest) = (gethash form source-map)
+	  when (and start end (not rest))
+	  return (return (values start end)))))
